@@ -30,7 +30,8 @@ usage:
     ia tasks <identifier> [--parameter=<k:v>...] [--tab-output]
     ia tasks <identifier> --cmd=<command> [--comment=<comment>]
                           [--task-args=<k:v>...] [--data=<k:v>...]
-                          [--tab-output]
+                          [--tab-output] [--reduced-priority]
+    ia tasks --get-rate-limit --cmd=<cmd>
     ia tasks --help
 
 options:
@@ -43,6 +44,11 @@ options:
                                   task is being submitted.
     -T, --tab-output              Output task info in tab-delimited columns.
     -a, --task-args=<k:v>...      Args to submit to the Tasks API.
+    -r, --reduced-priority        Submit task at a reduced priority.
+                                  Note that it may take a very long time for
+                                  your task to run after queued when this setting
+                                  is used [default: False].
+    -l, --get-rate-limit          Get rate limit info.
     -d, --data=<k:v>...           Additional data to send when submitting
                                   a task.
 
@@ -56,11 +62,13 @@ examples:
     ia tasks <id> --cmd make_undark.php --comment '<comment>'  # undark item
     ia tasks <id> --cmd make_dark.php --comment '<comment>'  # dark item
     ia tasks <id> --cmd fixer.php --task-args noop:1  # submit a noop fixer.php task
-    ia tasks <id> --cmd fixer.php --task-args 'noop:1;asr:1  # submit multiple fixer ops
+    ia tasks <id> --cmd fixer.php --task-args 'noop:1;asr:1'  # submit multiple fixer ops
+    ia tasks --get-rate-limit --cmd derive.php  # Get rate-limit information for a specific command
 """
 from __future__ import absolute_import, print_function
 import sys
 import warnings
+import json
 
 from docopt import docopt
 import six
@@ -73,6 +81,10 @@ def main(argv, session):
 
     # Tasks write API.
     if args['--cmd']:
+        if args['--get-rate-limit']:
+            r = session.get_tasks_api_rate_limit(args['--cmd'])
+            print(json.dumps(r))
+            sys.exit(0)
         data = get_args_dict(args['--data'], query_string=True)
         task_args = get_args_dict(args['--task-args'], query_string=True)
         data['args'] = task_args
@@ -80,11 +92,15 @@ def main(argv, session):
                                 args['--cmd'],
                                 comment=args['--comment'],
                                 priority=data.get('priority'),
+                                reduced_priority=args['--reduced-priority'],
                                 data=data)
         j = r.json()
         if j.get('success'):
             print('success: {}'.format(j.get('value', dict()).get('log')))
             sys.exit(0)
+        elif 'already queued/running' in j.get('error', ''):
+            print('success: {} task already queued/running'.format(args['--cmd']))
+            sys.exit(0)
         else:
             print('error: {}'.format(j.get('error')))
             sys.exit(1)
